Class: Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb

Overview

Client for the AssuredWorkloadsService service.

Service to manage AssuredWorkloads.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#location_path, #workload_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new AssuredWorkloadsService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the AssuredWorkloadsService client.

Yield Parameters:



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 148

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/assuredworkloads/v1beta1/assuredworkloads_service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @operations_client = Operations.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.universe_domain = @config.universe_domain
  end

  @assured_workloads_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @assured_workloads_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Instance Attribute Details

#operations_client::Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Operations (readonly)

Get the associated client for long-running operations.



211
212
213
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 211

def operations_client
  @operations_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the AssuredWorkloadsService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all AssuredWorkloadsService clients
::Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 62

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "AssuredWorkloads", "V1beta1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_workload.timeout = 60.0

    default_config.rpcs.update_workload.timeout = 60.0

    default_config.rpcs.delete_workload.timeout = 60.0
    default_config.rpcs.delete_workload.retry_policy = {
      initial_delay: 0.2, max_delay: 30.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_workload.timeout = 60.0
    default_config.rpcs.get_workload.retry_policy = {
      initial_delay: 0.2, max_delay: 30.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.analyze_workload_move.timeout = 60.0
    default_config.rpcs.analyze_workload_move.retry_policy = {
      initial_delay: 0.2, max_delay: 30.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_workloads.timeout = 60.0
    default_config.rpcs.list_workloads.retry_policy = {
      initial_delay: 0.2, max_delay: 30.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#analyze_workload_move(request, options = nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveResponse #analyze_workload_move(source: nil, project: nil, target: nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveResponse

Analyze if the source Assured Workloads can be moved to the target Assured Workload

Examples:

Basic example

require "google/cloud/assured_workloads/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveRequest.new

# Call the analyze_workload_move method.
result = client.analyze_workload_move request

# The returned object is of type Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveResponse.
p result

Overloads:

  • #analyze_workload_move(request, options = nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveResponse

    Pass arguments to analyze_workload_move via a request object, either of type Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #analyze_workload_move(source: nil, project: nil, target: nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveResponse

    Pass arguments to analyze_workload_move via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • source (::String) (defaults to: nil)

      The source type is a project-based workload. Specify the workloads's relative resource name, formatted as: "organizations/{ORGANIZATION_ID}/locations/{LOCATION_ID}/workloads/{WORKLOAD_ID}" For example: "organizations/123/locations/us-east1/workloads/assured-workload-1"

      Note: The following parameters are mutually exclusive: source, project. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • project (::String) (defaults to: nil)

      The source type is a project. Specify the project's relative resource name, formatted as either a project number or a project ID: "projects/{PROJECT_NUMBER}" or "projects/{PROJECT_ID}" For example: "projects/951040570662" when specifying a project number, or "projects/my-project-123" when specifying a project ID.

      Note: The following parameters are mutually exclusive: project, source. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • target (::String) (defaults to: nil)

      Required. The resource ID of the folder-based destination workload. This workload is where the source project will hypothetically be moved to. Specify the workload's relative resource name, formatted as: "organizations/{ORGANIZATION_ID}/locations/{LOCATION_ID}/workloads/{WORKLOAD_ID}" For example: "organizations/123/locations/us-east1/workloads/assured-workload-2"

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 750

def analyze_workload_move request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.analyze_workload_move..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.analyze_workload_move.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.analyze_workload_move.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assured_workloads_service_stub.call_rpc :analyze_workload_move, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the AssuredWorkloadsService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



118
119
120
121
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 118

def configure
  yield @config if block_given?
  @config
end

#create_workload(request, options = nil) ⇒ ::Gapic::Operation #create_workload(parent: nil, workload: nil, external_id: nil) ⇒ ::Gapic::Operation

Creates Assured Workload.

Examples:

Basic example

require "google/cloud/assured_workloads/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::AssuredWorkloads::V1beta1::CreateWorkloadRequest.new

# Call the create_workload method.
result = client.create_workload request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #create_workload(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to create_workload via a request object, either of type CreateWorkloadRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::AssuredWorkloads::V1beta1::CreateWorkloadRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_workload(parent: nil, workload: nil, external_id: nil) ⇒ ::Gapic::Operation

    Pass arguments to create_workload via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The resource name of the new Workload's parent. Must be of the form organizations/{org_id}/locations/{location_id}.

    • workload (::Google::Cloud::AssuredWorkloads::V1beta1::Workload, ::Hash) (defaults to: nil)

      Required. Assured Workload to create

    • external_id (::String) (defaults to: nil)

      Optional. A identifier associated with the workload and underlying projects which allows for the break down of billing costs for a workload. The value provided for the identifier will add a label to the workload and contained projects with the identifier as the value.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::Operation)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 283

def create_workload request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::CreateWorkloadRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_workload..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_workload.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_workload.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assured_workloads_service_stub.call_rpc :create_workload, request, options: options do |response, operation|
    response = ::Gapic::Operation.new response, @operations_client, options: options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_workload(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_workload(name: nil, etag: nil) ⇒ ::Google::Protobuf::Empty

Deletes the workload. Make sure that workload's direct children are already in a deleted state, otherwise the request will fail with a FAILED_PRECONDITION error. In addition to assuredworkloads.workload.delete permission, the user should also have orgpolicy.policy.set permission on the deleted folder to remove Assured Workloads OrgPolicies.

Examples:

Basic example

require "google/cloud/assured_workloads/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::AssuredWorkloads::V1beta1::DeleteWorkloadRequest.new

# Call the delete_workload method.
result = client.delete_workload request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_workload(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_workload via a request object, either of type DeleteWorkloadRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::AssuredWorkloads::V1beta1::DeleteWorkloadRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_workload(name: nil, etag: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_workload via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name field is used to identify the workload. Format: organizations/{org_id}/locations/{location_id}/workloads/{workload_id}

    • etag (::String) (defaults to: nil)

      Optional. The etag of the workload. If this is provided, it must match the server's etag.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 561

def delete_workload request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::DeleteWorkloadRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_workload..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_workload.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_workload.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assured_workloads_service_stub.call_rpc :delete_workload, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_workload(request, options = nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload #get_workload(name: nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload

Gets Assured Workload associated with a CRM Node

Examples:

Basic example

require "google/cloud/assured_workloads/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::AssuredWorkloads::V1beta1::GetWorkloadRequest.new

# Call the get_workload method.
result = client.get_workload request

# The returned object is of type Google::Cloud::AssuredWorkloads::V1beta1::Workload.
p result

Overloads:

  • #get_workload(request, options = nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload

    Pass arguments to get_workload via a request object, either of type GetWorkloadRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::AssuredWorkloads::V1beta1::GetWorkloadRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_workload(name: nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload

    Pass arguments to get_workload via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the Workload to fetch. This is the workloads's relative path in the API, formatted as "organizations/{organization_id}/locations/{location_id}/workloads/{workload_id}". For example, "organizations/123/locations/us-east1/workloads/assured-workload-1".

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 650

def get_workload request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::GetWorkloadRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_workload..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_workload.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_workload.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assured_workloads_service_stub.call_rpc :get_workload, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_workloads(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::AssuredWorkloads::V1beta1::Workload> #list_workloads(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::AssuredWorkloads::V1beta1::Workload>

Lists Assured Workloads under a CRM Node.

Examples:

Basic example

require "google/cloud/assured_workloads/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::AssuredWorkloads::V1beta1::ListWorkloadsRequest.new

# Call the list_workloads method.
result = client.list_workloads request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::AssuredWorkloads::V1beta1::Workload.
  p item
end

Overloads:

  • #list_workloads(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::AssuredWorkloads::V1beta1::Workload>

    Pass arguments to list_workloads via a request object, either of type ListWorkloadsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::AssuredWorkloads::V1beta1::ListWorkloadsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_workloads(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::AssuredWorkloads::V1beta1::Workload>

    Pass arguments to list_workloads via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Parent Resource to list workloads from. Must be of the form organizations/{org_id}/locations/{location}.

    • page_size (::Integer) (defaults to: nil)

      Page size.

    • page_token (::String) (defaults to: nil)

      Page token returned from previous request. Page token contains context from previous request. Page token needs to be passed in the second and following requests.

    • filter (::String) (defaults to: nil)

      A custom filter for filtering by properties of a workload. At this time, only filtering by labels is supported.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 841

def list_workloads request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::ListWorkloadsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_workloads..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_workloads.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_workloads.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assured_workloads_service_stub.call_rpc :list_workloads, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @assured_workloads_service_stub, :list_workloads, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


218
219
220
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 218

def logger
  @assured_workloads_service_stub.logger
end

#restrict_allowed_resources(request, options = nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::RestrictAllowedResourcesResponse #restrict_allowed_resources(name: nil, restriction_type: nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::RestrictAllowedResourcesResponse

Restrict the list of resources allowed in the Workload environment. The current list of allowed products can be found at https://cloud.google.com/assured-workloads/docs/supported-products In addition to assuredworkloads.workload.update permission, the user should also have orgpolicy.policy.set permission on the folder resource to use this functionality.

Examples:

Basic example

require "google/cloud/assured_workloads/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::AssuredWorkloads::V1beta1::RestrictAllowedResourcesRequest.new

# Call the restrict_allowed_resources method.
result = client.restrict_allowed_resources request

# The returned object is of type Google::Cloud::AssuredWorkloads::V1beta1::RestrictAllowedResourcesResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 466

def restrict_allowed_resources request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::RestrictAllowedResourcesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.restrict_allowed_resources..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.restrict_allowed_resources.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.restrict_allowed_resources.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assured_workloads_service_stub.call_rpc :restrict_allowed_resources, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


128
129
130
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 128

def universe_domain
  @assured_workloads_service_stub.universe_domain
end

#update_workload(request, options = nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload #update_workload(workload: nil, update_mask: nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload

Updates an existing workload. Currently allows updating of workload display_name and labels. For force updates don't set etag field in the Workload. Only one update operation per workload can be in progress.

Examples:

Basic example

require "google/cloud/assured_workloads/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::AssuredWorkloads::V1beta1::UpdateWorkloadRequest.new

# Call the update_workload method.
result = client.update_workload request

# The returned object is of type Google::Cloud::AssuredWorkloads::V1beta1::Workload.
p result

Overloads:

  • #update_workload(request, options = nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload

    Pass arguments to update_workload via a request object, either of type UpdateWorkloadRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::AssuredWorkloads::V1beta1::UpdateWorkloadRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_workload(workload: nil, update_mask: nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload

    Pass arguments to update_workload via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 378

def update_workload request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::UpdateWorkloadRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_workload..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_workload.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_workload.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @assured_workloads_service_stub.call_rpc :update_workload, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end