Class: Google::Cloud::AssuredWorkloads::V1beta1::Workload::SaaEnrollmentResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/assuredworkloads/v1beta1/assuredworkloads.rb

Overview

Signed Access Approvals (SAA) enrollment response.

Defined Under Namespace

Modules: SetupError, SetupState

Instance Attribute Summary collapse

Instance Attribute Details

#setup_errors::Array<::Google::Cloud::AssuredWorkloads::V1beta1::Workload::SaaEnrollmentResponse::SetupError>

Returns Indicates SAA enrollment setup error if any.

Returns:



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'proto_docs/google/cloud/assuredworkloads/v1beta1/assuredworkloads.rb', line 433

class SaaEnrollmentResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setup state of SAA enrollment.
  module SetupState
    # Unspecified.
    SETUP_STATE_UNSPECIFIED = 0

    # SAA enrollment pending.
    STATUS_PENDING = 1

    # SAA enrollment comopleted.
    STATUS_COMPLETE = 2
  end

  # Setup error of SAA enrollment.
  module SetupError
    # Unspecified.
    SETUP_ERROR_UNSPECIFIED = 0

    # Invalid states for all customers, to be redirected to AA UI for
    # additional details.
    ERROR_INVALID_BASE_SETUP = 1

    # Returned when there is not an EKM key configured.
    ERROR_MISSING_EXTERNAL_SIGNING_KEY = 2

    # Returned when there are no enrolled services or the customer is
    # enrolled in CAA only for a subset of services.
    ERROR_NOT_ALL_SERVICES_ENROLLED = 3

    # Returned when exception was encountered during evaluation of other
    # criteria.
    ERROR_SETUP_CHECK_FAILED = 4
  end
end

#setup_status::Google::Cloud::AssuredWorkloads::V1beta1::Workload::SaaEnrollmentResponse::SetupState

Returns Indicates SAA enrollment status of a given workload.

Returns:



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'proto_docs/google/cloud/assuredworkloads/v1beta1/assuredworkloads.rb', line 433

class SaaEnrollmentResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setup state of SAA enrollment.
  module SetupState
    # Unspecified.
    SETUP_STATE_UNSPECIFIED = 0

    # SAA enrollment pending.
    STATUS_PENDING = 1

    # SAA enrollment comopleted.
    STATUS_COMPLETE = 2
  end

  # Setup error of SAA enrollment.
  module SetupError
    # Unspecified.
    SETUP_ERROR_UNSPECIFIED = 0

    # Invalid states for all customers, to be redirected to AA UI for
    # additional details.
    ERROR_INVALID_BASE_SETUP = 1

    # Returned when there is not an EKM key configured.
    ERROR_MISSING_EXTERNAL_SIGNING_KEY = 2

    # Returned when there are no enrolled services or the customer is
    # enrolled in CAA only for a subset of services.
    ERROR_NOT_ALL_SERVICES_ENROLLED = 3

    # Returned when exception was encountered during evaluation of other
    # criteria.
    ERROR_SETUP_CHECK_FAILED = 4
  end
end