Class: Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb
Overview
Client for the AssuredWorkloadsService service.
Service to manage AssuredWorkloads.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#operations_client ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the AssuredWorkloadsService Client class.
Instance Method Summary collapse
-
#analyze_workload_move(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveResponse
Analyze if the source Assured Workloads can be moved to the target Assured Workload.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the AssuredWorkloadsService Client instance.
-
#create_workload(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Creates Assured Workload.
-
#delete_workload(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes the workload.
-
#get_workload(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload
Gets Assured Workload associated with a CRM Node.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new AssuredWorkloadsService client object.
-
#list_workloads(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::AssuredWorkloads::V1beta1::Workload>
Lists Assured Workloads under a CRM Node.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#restrict_allowed_resources(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::RestrictAllowedResourcesResponse
Restrict the list of resources allowed in the Workload environment.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_workload(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload
Updates an existing workload.
Methods included from Paths
#location_path, #workload_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new AssuredWorkloadsService client object.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 148 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/assuredworkloads/v1beta1/assuredworkloads_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @assured_workloads_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @assured_workloads_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Instance Attribute Details
#operations_client ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::AssuredWorkloadsService::Operations (readonly)
Get the associated client for long-running operations.
211 212 213 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 211 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the AssuredWorkloadsService Client class.
See Configuration for a description of the configuration fields.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 62 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "AssuredWorkloads", "V1beta1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_workload.timeout = 60.0 default_config.rpcs.update_workload.timeout = 60.0 default_config.rpcs.delete_workload.timeout = 60.0 default_config.rpcs.delete_workload.retry_policy = { initial_delay: 0.2, max_delay: 30.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_workload.timeout = 60.0 default_config.rpcs.get_workload.retry_policy = { initial_delay: 0.2, max_delay: 30.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.analyze_workload_move.timeout = 60.0 default_config.rpcs.analyze_workload_move.retry_policy = { initial_delay: 0.2, max_delay: 30.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_workloads.timeout = 60.0 default_config.rpcs.list_workloads.retry_policy = { initial_delay: 0.2, max_delay: 30.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#analyze_workload_move(request, options = nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveResponse #analyze_workload_move(source: nil, project: nil, target: nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveResponse
Analyze if the source Assured Workloads can be moved to the target Assured Workload
750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 750 def analyze_workload_move request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::AnalyzeWorkloadMoveRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.analyze_workload_move..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.analyze_workload_move.timeout, metadata: , retry_policy: @config.rpcs.analyze_workload_move.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assured_workloads_service_stub.call_rpc :analyze_workload_move, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the AssuredWorkloadsService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
118 119 120 121 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 118 def configure yield @config if block_given? @config end |
#create_workload(request, options = nil) ⇒ ::Gapic::Operation #create_workload(parent: nil, workload: nil, external_id: nil) ⇒ ::Gapic::Operation
Creates Assured Workload.
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 283 def create_workload request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::CreateWorkloadRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_workload..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_workload.timeout, metadata: , retry_policy: @config.rpcs.create_workload.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assured_workloads_service_stub.call_rpc :create_workload, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_workload(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_workload(name: nil, etag: nil) ⇒ ::Google::Protobuf::Empty
Deletes the workload. Make sure that workload's direct children are already in a deleted state, otherwise the request will fail with a FAILED_PRECONDITION error. In addition to assuredworkloads.workload.delete permission, the user should also have orgpolicy.policy.set permission on the deleted folder to remove Assured Workloads OrgPolicies.
561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 561 def delete_workload request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::DeleteWorkloadRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_workload..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_workload.timeout, metadata: , retry_policy: @config.rpcs.delete_workload.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assured_workloads_service_stub.call_rpc :delete_workload, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_workload(request, options = nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload #get_workload(name: nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload
Gets Assured Workload associated with a CRM Node
650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 650 def get_workload request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::GetWorkloadRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_workload..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_workload.timeout, metadata: , retry_policy: @config.rpcs.get_workload.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assured_workloads_service_stub.call_rpc :get_workload, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_workloads(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::AssuredWorkloads::V1beta1::Workload> #list_workloads(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::AssuredWorkloads::V1beta1::Workload>
Lists Assured Workloads under a CRM Node.
841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 841 def list_workloads request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::ListWorkloadsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_workloads..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_workloads.timeout, metadata: , retry_policy: @config.rpcs.list_workloads.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assured_workloads_service_stub.call_rpc :list_workloads, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @assured_workloads_service_stub, :list_workloads, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
218 219 220 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 218 def logger @assured_workloads_service_stub.logger end |
#restrict_allowed_resources(request, options = nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::RestrictAllowedResourcesResponse #restrict_allowed_resources(name: nil, restriction_type: nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::RestrictAllowedResourcesResponse
Restrict the list of resources allowed in the Workload environment. The current list of allowed products can be found at https://cloud.google.com/assured-workloads/docs/supported-products In addition to assuredworkloads.workload.update permission, the user should also have orgpolicy.policy.set permission on the folder resource to use this functionality.
466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 466 def restrict_allowed_resources request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::RestrictAllowedResourcesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.restrict_allowed_resources..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.restrict_allowed_resources.timeout, metadata: , retry_policy: @config.rpcs.restrict_allowed_resources.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assured_workloads_service_stub.call_rpc :restrict_allowed_resources, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
128 129 130 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 128 def universe_domain @assured_workloads_service_stub.universe_domain end |
#update_workload(request, options = nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload #update_workload(workload: nil, update_mask: nil) ⇒ ::Google::Cloud::AssuredWorkloads::V1beta1::Workload
Updates an existing workload. Currently allows updating of workload display_name and labels. For force updates don't set etag field in the Workload. Only one update operation per workload can be in progress.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/google/cloud/assured_workloads/v1beta1/assured_workloads_service/client.rb', line 378 def update_workload request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::AssuredWorkloads::V1beta1::UpdateWorkloadRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_workload..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AssuredWorkloads::V1beta1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_workload.timeout, metadata: , retry_policy: @config.rpcs.update_workload.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @assured_workloads_service_stub.call_rpc :update_workload, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |